%define        rel 00
#% define        tclver %(echo %version | cut -d. -f1-3)
#% define        tclver %(echo %version | sed "s|\.0$||")
%define        tclver %version
%define        real_version %(echo %version|sed "s|\.\\([0-9][0-9]\\)|\\1|g"|tr . 0)00
%define        doc_version %(echo %version |cut -d. -f1-3|sed "s|\.\\([0-9][0-9]\\)|\\1|g"|tr . 0)00
%if "%{_host}" == "%{_build}"
%ifnarch arm
%define        with_check   1
%endif
%endif
%define        year %(date +%Y)
#% define        year 2020

Name:          libsqlite
Version:       3.38.0
Release:       1mamba
Summary:       A C library that implements an embeddable SQL database engine
Group:         System/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.sqlite.org/index.html
Source0:       https://www.sqlite.org/%{year}/sqlite-autoconf-%{real_version}.tar.gz
Source1:       https://www.sqlite.org/%{year}/sqlite-doc-%{doc_version}.zip
Patch0:        %{name}-3.7.11.0-enable_column_metadata.patch
Patch1:        %{name}-3.6.18-libdl.patch
# support a system-wide lemon template
Patch2:        libsqlite-3.6.23.1-lemon-system-template.patch
Patch3:        libsqlite-3.7.4-wal2-nodirsync.patch
License:       Public Domain
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libedit-devel
BuildRequires: libncurses-devel
BuildRequires: libz-devel
## AUTOBUILDREQ-END
BuildRequires: libtcl-devel
Provides:      sqlite3 = %{?epoch:%epoch:}%{version}-%{release}
Obsoletes:     sqlite3 <= 3.33.0.0
Provides:      libsqlite3 = %{?epoch:%epoch:}%{version}-%{release}
Obsoletes:     libsqlite3 <= 3.33.0.0

%description
SQLite is a C library that implements an embeddable SQL database engine.
Programs that link with the SQLite library can have SQL database access without running a separate RDBMS process.

%package devel
Summary:       Static libraries and headers for %{name}
Group:         Development/Libraries
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Provides:      sqlite3-devel = %{?epoch:%epoch:}%{version}-%{release}
Obsoletes:     sqlite3-devel <= 3.33.0.0
Provides:      libsqlite3-devel = %{?epoch:%epoch:}%{version}-%{release}
Obsoletes:     libsqlite3-devel <= 3.33.0.0

%description devel
SQLite is a C library that implements an embeddable SQL database engine.
Programs that link with the SQLite library can have SQL database access without running a separate RDBMS process.
This package contains static libraries and header files needed for development.

%package doc
Summary:       Documentation for SQLite
Group:         Documentation

%description doc
SQLite is a C library that implements an embeddable SQL database engine.
This package contains most of the static HTML files that comprise the www.sqlite.org website, including all of the SQL Syntax and the C/C++ interface specs and other miscellaneous documentation.

%package -n lemon
Group:         Development/Tools
Summary:       A parser generator

%description -n lemon
Lemon is an LALR(1) parser generator for C or C++. It does the same job as bison and yacc. But lemon is not another bison or yacc clone. It uses a different grammar syntax which is designed to reduce the number of coding errors. Lemon also uses a more sophisticated parsing engine that is faster than yacc and bison and which is both reentrant and thread-safe. Furthermore, Lemon implements features that can be used to eliminate resource leaks, making is suitable for use in long-running programs such as graphical user interfaces or embedded controllers.

%package tools
Summary:       Tools for %{name}
Group:         Applications/Databases
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Provides:      sqlite3-tools = %{?epoch:%epoch:}%{version}-%{release}
Obsoletes:     sqlite3-tools <= 3.33.0.0

%description tools
A standalone command-line access program (sqlite3) that can be used to administer an SQLite database and which serves as an example of how to use the SQLite library.

%package tcl
Summary:       Tcl binding for %{name}
Group:         Development/Bindings
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Provides:      sqlite3-tcl = %{?epoch:%epoch:}%{version}-%{release}
Obsoletes:     sqlite3-tcl <= 3.33.0.0
Provides:      tcl-sqlite3 = %{?epoch:%epoch:}%{version}-%{release}
Obsoletes:     tcl-sqlite3 <= 3.33.0.0

%description tcl
Tcl binding for %{name}.

%debug_package

%prep
%setup -q -n sqlite-autoconf-%{real_version} -a1
%patch0 -p1
#%patch1 -p1
#%patch2 -p0
#%patch3 -p1

rm -f sqlite-doc-%{real_version}%{?rel}/search

%build
## FIXME: autoconf required to apply patch1 that fixes sqlite3.pc
#autoconf
# https://bugzilla.redhat.com/show_bug.cgi?id=485635 -DSQLITE_ENABLE_FTS3=1
export CFLAGS="$RPM_OPT_FLAGS \
   -DSQLITE_ENABLE_COLUMN_METADATA=1 \
   -DSQLITE_DISABLE_DIRSYNC=1 \
   -DSQLITE_ENABLE_FTS3 \
   -DSQLITE_ENABLE_RTREE=1\
   -DSQLITE_SECURE_DELETE=1 \
   -DSQLITE_ENABLE_UNLOCK_NOTIFY=1 \
   -DSQLITE_ENABLE_DBSTAT_VTAB=1 \
    -Wall -fno-strict-aliasing"

%configure \
   --enable-threadsafe \
   --enable-threads-override-locks \
   --enable-load-extension

#  --enable-incore-db

sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make \
%if "%{_host}" != "%{_build}"
   TLIBS="-lpthread -ldl"
%endif

cd tea
%configure \
   --with-tclinclude=%{_includedir} \
   --libdir=%{_prefix}/lib
%make
cd ..

#make doc

#make -k fulltest

%install
[ %{buildroot} != / ] && rm -rf "%{buildroot}"
%makeinstall

cd tea
%makeinstall
cd ..

install -D -m644 sqlite3.1 %{buildroot}%{_mandir}/man1/sqlite3.1

#chmod 755 %{buildroot}%{_prefix}/lib/tcl*/sqlite?/*.so
#sed -i "s,%{buildroot},," %{buildroot}%{_prefix}/lib/tcl?.?/sqlite?/pkgIndex.tcl

mkdir -p %{buildroot}%{_docdir}
cp -a sqlite-doc-%{doc_version} %{buildroot}%{_docdir}/
rm -f %{buildroot}%{_docdir}/sqlite-doc-%{doc_version}/search
rm -rf %{buildroot}%{_docdir}/sqlite-doc-%{doc_version}/search.d

#%if "%{_host}" == "%{_build}"
#mkdir -p %{buildroot}%{_datadir}/lemon
#install -m 755 lemon %{buildroot}%{_bindir}/lemon
#install -m 644 tool/lempar.c %{buildroot}%{_datadir}/lemon/lempar.c
#%endif

%if "%with_check" == "1"
%check
make test || :
%endif

%clean
[ %{buildroot} != / ] && rm -rf "%{buildroot}"

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-, root, root)
%{_libdir}/libsqlite3.so.*
#%doc README

%files devel
%defattr(-, root, root)
%{_includedir}/*.h
%{_libdir}/*.a
%{_libdir}/*.la
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files doc
%defattr(-, root, root)
%doc %{_docdir}/sqlite-doc-%{doc_version}

#%if "%{_host}" == "%{_build}"
#%files -n lemon
#%defattr(-, root, root)
#%{_bindir}/lemon
#%{_datadir}/lemon
#%endif

%files tools
%defattr(-, root, root)
%{_bindir}/sqlite3
%{_mandir}/man1/*

%files tcl
%defattr(-, root, root)
%dir %{_prefix}/lib/sqlite%{tclver}
%{_prefix}/lib/sqlite%{tclver}/libsqlite%{tclver}.so
%{_prefix}/lib/sqlite%{tclver}/pkgIndex.tcl
%{_mandir}/mann/*

%changelog
* Fri Mar 04 2022 Automatic Build System <autodist@mambasoft.it> 3.38.0-1mamba
- automatic version update by autodist

* Fri Jan 07 2022 Automatic Build System <autodist@mambasoft.it> 3.37.2-1mamba
- automatic version update by autodist

* Fri Dec 31 2021 Automatic Build System <autodist@mambasoft.it> 3.37.1-1mamba
- automatic version update by autodist

* Sat Nov 27 2021 Automatic Build System <autodist@mambasoft.it> 3.37.0-1mamba
- automatic version update by autodist

* Sat Jun 19 2021 Automatic Build System <autodist@mambasoft.it> 3.36.0-1mamba
- automatic version update by autodist

* Fri May 21 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 3.35.5-1mamba
- update to 3.35.5

* Sun Sep 06 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 3.33.0.0-1mamba
- update to 3.33.0.0

* Mon May 11 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 3.31.1.0-1mamba
- update to 3.31.1.0

* Sun Oct 27 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 3.30.1.0-1mamba
- update to 3.30.01.00

* Thu Aug 01 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 3.29.0.0-1mamba
- update to 3.29.0.0

* Fri Jan 04 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 3.26.0.0-1mamba
- update to 3.26.0.0

* Mon Jun 25 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 3.24.0.0-3mamba
- really apply fix at previous release

* Sat Jun 16 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 3.24.0.0-2mamba
- libsqlite-doc: remove search and search.d/* requiring missing tclsh.docsrc

* Sat Jun 16 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 3.24.0.0-1mamba
- update to 3.24.0.0

* Sat Dec 24 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 3.15.2.0-2mamba
- rebuilt with -DSQLITE_ENABLE_DBSTAT_VTAB=1 for thunderbird

* Fri Dec 16 2016 Automatic Build System <autodist@mambasoft.it> 3.15.2.0-1mamba
- automatic version update by autodist

* Sat Oct 08 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 3.14.2.0-1mamba
- update to 3.14.2.0

* Fri Apr 22 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 3.12.2.0-1mamba
- update to 3.12.2.0

* Tue Jan 26 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 3.10.2.0-1mamba
- update to 3.10.2.0

* Wed Nov 18 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.9.2.0-1mamba
- update to 3.9.2.0

* Thu Jul 30 2015 Automatic Build System <autodist@mambasoft.it> 3.8.11.1-1mamba
- automatic version update by autodist

* Thu May 21 2015 Automatic Build System <autodist@mambasoft.it> 3.8.10.2-1mamba
- automatic version update by autodist

* Sat May 09 2015 Automatic Build System <autodist@mambasoft.it> 3.8.10.1-1mamba
- automatic version update by autodist

* Sat May 09 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.8.10.0-1mamba
- update to 3.8.10.0

* Sat May 09 2015 Automatic Build System <autodist@mambasoft.it> 3.8.10-1mamba
- automatic version update by autodist

* Sat Apr 18 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.8.9.0-1mamba
- update to 3.8.9.0

* Sun Mar 01 2015 Automatic Build System <autodist@mambasoft.it> 3.8.8.3-1mamba
- automatic version update by autodist

* Sat Jan 31 2015 Automatic Build System <autodist@mambasoft.it> 3.8.8.2-1mamba
- automatic version update by autodist

* Wed Jan 21 2015 Automatic Build System <autodist@mambasoft.it> 3.8.8.1-1mamba
- automatic version update by autodist

* Wed Dec 10 2014 Automatic Build System <autodist@mambasoft.it> 3.8.7.4-1mamba
- automatic version update by autodist

* Sat Dec 06 2014 Automatic Build System <autodist@mambasoft.it> 3.8.7.3-1mamba
- automatic version update by autodist

* Wed Nov 19 2014 Automatic Build System <autodist@mambasoft.it> 3.8.7.2-1mamba
- automatic version update by autodist

* Thu Oct 30 2014 Automatic Build System <autodist@mambasoft.it> 3.8.7.1-1mamba
- automatic version update by autodist

* Sun Oct 26 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.8.7.0-1mamba
- update to 3.8.7.0

* Sun Oct 26 2014 Automatic Build System <autodist@mambasoft.it> 3.8.7-1mamba
- automatic version update by autodist

* Mon Aug 18 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.8.6.0-1mamba
- update to 3.8.6.0

* Mon Jun 09 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.8.5.0-1mamba
- update to 3.8.5.0

* Fri Apr 04 2014 Automatic Build System <autodist@mambasoft.it> 3.8.4.3-1mamba
- automatic version update by autodist

* Thu Mar 27 2014 Automatic Build System <autodist@mambasoft.it> 3.8.4.2-1mamba
- automatic version update by autodist

* Tue Mar 11 2014 Automatic Build System <autodist@mambasoft.it> 3.8.4.1-1mamba
- automatic version update by autodist

* Wed Feb 12 2014 Automatic Build System <autodist@mambasoft.it> 3.8.3.1-1mamba
- automatic version update by autodist

* Wed Feb 05 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.8.3.0-1mamba
- update to 3.8.3.0

* Sun Dec 08 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 3.8.2.0-1mamba
- update to 3.8.2.0

* Fri Nov 22 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 3.8.1.0-1mamba
- update to 3.8.1.0

* Wed Sep 04 2013 Automatic Build System <autodist@mambasoft.it> 3.8.0.2-1mamba
- automatic version update by autodist

* Fri Aug 30 2013 Automatic Build System <autodist@mambasoft.it> 3.8.0.1-1mamba
- automatic version update by autodist

* Mon Aug 26 2013 Automatic Build System <autodist@mambasoft.it> 3.8.0.0-1mamba
- update to 3.8.0.0

* Wed May 22 2013 Automatic Build System <autodist@mambasoft.it> 3.7.17.0-1mamba
- update to 3.7.17.0

* Fri Apr 12 2013 Automatic Build System <autodist@mambasoft.it> 3.7.16.2-1mamba
- automatic version update by autodist

* Sat Mar 30 2013 Automatic Build System <autodist@mambasoft.it> 3.7.16.1-1mamba
- automatic version update by autodist

* Thu Mar 28 2013 Automatic Build System <autodist@mambasoft.it> 3.7.16.0-1mamba
- update to 3.7.16.0

* Thu Jan 10 2013 Automatic Build System <autodist@mambasoft.it> 3.7.15.2-1mamba
- automatic version update by autodist

* Thu Dec 20 2012 Automatic Build System <autodist@mambasoft.it> 3.7.15.1-1mamba
- automatic version update by autodist

* Mon Dec 17 2012 Automatic Build System <autodist@mambasoft.it> 3.7.15.0-1mamba
- update to 3.7.15.0

* Sun Oct 07 2012 Automatic Build System <autodist@mambasoft.it> 3.7.14.1-1mamba
- update to 3.7.14.1

* Tue Sep 04 2012 Automatic Build System <autodist@mambasoft.it> 3.7.14.0-1mamba
- update to 3.7.14.0

* Tue Jun 12 2012 Automatic Build System <autodist@mambasoft.it> 3.7.13.0-1mamba
- update to 3.7.13.0

* Wed May 23 2012 Automatic Build System <autodist@mambasoft.it> 3.7.12.1-1mamba
- automatic version update by autodist

* Sat Apr 28 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.7.11.0-1mamba
- update to 3.7.11.0

* Thu Nov 17 2011 Automatic Build System <autodist@mambasoft.it> 3.7.9.0-1mamba
- update to 3.7.9.0

* Sat Oct 01 2011 Automatic Build System <autodist@mambasoft.it> 3.7.8.0-1mamba
- update to 3.7.8.0

* Tue Jul 26 2011 Automatic Build System <autodist@mambasoft.it> 3.7.7.1-1mamba
- update to 3.7.7.1

* Thu Jul 21 2011 Automatic Build System <autodist@mambasoft.it> 3.7.6.3-1mamba
- update to 3.7.6.3

* Sat Apr 09 2011 Ercole 'ercolinux' Carpanetto 3.7.5-3mamba
- fixed a typo in config 

* Sat Apr 09 2011 Ercole 'ercolinux' Carpanetto 3.7.5-2mamba
- rebuild

* Sun Feb 20 2011 gil <puntogil@libero.it> 3.7.5-1mamba
- update to 3.7.5
- add SQLITE_ENABLE_FTS3=3

* Wed Jan 26 2011 gil <puntogil@libero.it> 3.7.4-1mamba
- update to 3.7.4
- add SQLITE_ENABLE_UNLOCK_NOTIFY=1
- add new sub package doc

* Fri Oct 08 2010 Automatic Build System <autodist@mambasoft.it> 3.7.3-1mamba
- automatic update to 3.7.3 by autodist

* Sat Sep 11 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 3.7.2-1mamba
- update to 3.7.2
- compiled with SQLITE_SECURE_DELETE and SQLITE_ENABLE_FTS3 (not =1) as required by xulrunner 1.9.2.9

* Mon Aug 23 2010 Automatic Build System <autodist@mambasoft.it> 3.7.1-1mamba
- automatic update to 3.7.1 by autodist

* Wed Aug 04 2010 Automatic Build System <autodist@mambasoft.it> 3.7.0.1-1mamba
- automatic update to 3.7.0.1 by autodist

* Thu Jul 22 2010 Automatic Build System <autodist@mambasoft.it> 3.7.0-1mamba
- automatic update to 3.7.0 by autodist

* Wed Jun 30 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.23.1-5mamba
- run autoconf to apply patch1 and fix sqlite3.pc

* Sat Jun 26 2010 Automatic Build System <autodist@mambasoft.it> 3.6.23.1-4mamba
- automatic rebuild by autodist

* Wed Jun 16 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.23.1-3mamba
- removed lemon binary from sqlite-tools package
- specfile fixed for cross-platform build (don't provide lemon package)

* Tue May 18 2010 gil <puntogil@libero.it> 3.6.23.1-2mamba
- edit spec file
- added check section
- added new subpackage(s): doc, lemon
- edit source 1
- edit configure options: enable-threads-override-locks

* Mon Apr 12 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.23.1-1mamba
- update to 3.6.23.1

* Thu Nov 05 2009 Automatic Build System <autodist@mambasoft.it> 3.6.20-1mamba
- automatic update to 3.6.20 by autodist

* Wed Oct 14 2009 Automatic Build System <autodist@mambasoft.it> 3.6.19-1mamba
- automatic update to 3.6.19 by autodist

* Mon Oct 05 2009 Davide Madrisan <davide.madrisan@gmail.com> 3.6.18-2mamba
- fix build with --enable-load-extension

* Sat Sep 12 2009 Automatic Build System <autodist@mambasoft.it> 3.6.18-1mamba
- automatic update to 3.6.18 by autodist

* Tue Aug 11 2009 Automatic Build System <autodist@mambasoft.it> 3.6.17-1mamba
- automatic update to 3.6.17 by autodist

* Thu Jul 09 2009 Davide Madrisan <davide.madrisan@gmail.com> 3.6.16-2mamba
- enable loading of external extensions

* Sat Jun 27 2009 Automatic Build System <autodist@mambasoft.it> 3.6.16-1mamba
- automatic update to 3.6.16 by autodist

* Mon Jun 15 2009 Automatic Build System <autodist@mambasoft.it> 3.6.15-1mamba
- automatic update to 3.6.15 by autodist

* Tue May 26 2009 Automatic Build System <autodist@mambasoft.it> 3.6.14.2-1mamba
- automatic update to 3.6.14.2 by autodist

* Tue May 19 2009 Automatic Build System <autodist@mambasoft.it> 3.6.14.1-1mamba
- automatic update to 3.6.14.1 by autodist

* Fri May 08 2009 Automatic Build System <autodist@mambasoft.it> 3.6.14-1mamba
- automatic update to 3.6.14 by autodist

* Mon Apr 13 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.13-1mamba
- automatic update to 3.6.13 by autodist

* Tue Mar 31 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.12-1mamba
- automatic update to 3.6.12 by autodist

* Wed Feb 18 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.11-1mamba
- automatic update to 3.6.11 by autodist

* Fri Jan 16 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.10-1mamba
- automatic update to 3.6.10 by autodist

* Thu Jan 15 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.8-2mamba
- build with SQLITE_ENABLE_COLUMN_METADATA define

* Tue Jan 13 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.8-1mamba
- automatic update to 3.6.8 by autodist

* Wed Dec 17 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.7-1mamba
- automatic update to 3.6.7 by autodist

* Thu Nov 27 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.6.2-1mamba
- automatic update to 3.6.6.2 by autodist

* Sun Nov 23 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.6.1-1mamba
- automatic update to 3.6.6.1 by autodist

* Thu Nov 20 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.6-1mamba
- automatic update to 3.6.6 by autodist

* Thu Nov 13 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.5-1mamba
- automatic update to 3.6.5 by autodist

* Thu Oct 16 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.4-1mamba
- automatic update to 3.6.4 by autodist

* Tue Sep 23 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.3-1mamba
- automatic update to 3.6.3 by autodist

* Mon Sep 01 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.2-1mamba
- update to 3.6.2

* Thu Aug 14 2008 gil <puntogil@libero.it> 3.6.1-1mamba
- update to 3.6.1
- buld with libtcl85

* Fri Jun 20 2008 gil <puntogil@libero.it> 3.5.9-1mamba
- update to 3.5.9

* Thu Jul 05 2007 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 3.4.0-1mamba
- update to 3.4.0
- package name modified (was libsqlite3)
- sqlite3-tools renamed to libsqlite-tools
- tcl-sqlite3 renamed to libsqlite-tcl

* Tue Dec 20 2005 Davide Madrisan <davide.madrisan@qilinux.it> 3.2.8-1qilnx
- update to version 3.2.8 by autospec
- new packages tcl-sqlite3 and sqlite3-tools
- added manpage for the sqlite3 tool

* Mon Sep 26 2005 Davide Madrisan <davide.madrisan@qilinux.it> 3.2.7-1qilnx
- update to version 3.2.7 by autospec

* Mon Sep 19 2005 Davide Madrisan <davide.madrisan@qilinux.it> 3.2.6-1qilnx
- update to version 3.2.6 by autospec

* Mon Feb 21 2005 Davide Madrisan <davide.madrisan@qilinux.it> 3.1.3-2qilnx
- added missing `provides' and `obsoletes' entries in the specfile preamble

* Mon Feb 21 2005 Davide Madrisan <davide.madrisan@qilinux.it> 3.1.3-1qilnx
- update to version 3.1.3 by autospec
- new package name (libsqlite3)
- moved to QiLinux official devel branch

* Mon Sep 27 2004 Matteo Bernasconi <voyagernm@virgilio.it> 3.0.7-1qilnx
- first build
